@@ -103,16 +103,6 @@ class Channel(TembaObject):
     created_on = DatetimeField()
 
 
-class ChannelEvent(TembaObject):
-    id = IntegerField()
-    type = SimpleField()
-    contact = ObjectField(item_class=ObjectRef)
-    channel = ObjectField(item_class=ObjectRef)
-    extra = SimpleField()
-    occurred_on = DatetimeField()
-    created_on = DatetimeField()
-
-
 class Classifier(TembaObject):
     uuid = SimpleField()
     type = SimpleField()
@@ -143,7 +133,6 @@ class Export(TembaObject):
     fields = ListField()
     groups = ListField()
 
-
 class Field(TembaObject):
     key = SimpleField()
     name = SimpleField()
@@ -273,12 +262,11 @@ class Run(TembaObject):
         time = DatetimeField()
 
     class Value(TembaObject):
+        name = SimpleField()
         value = SimpleField()
         category = SimpleField()
         node = SimpleField()
         time = DatetimeField()
-        name = SimpleField()
-        input = SimpleField()
 
     uuid = SimpleField()
     flow = ObjectField(item_class=ObjectRef)
